dftomat: Convert Data Frame to Numeric Matrix

View source: R/dftomat.R

dftomatR Documentation

Convert Data Frame to Numeric Matrix

Description

This function converts a data frame into a numeric matrix. If the data frame contains factor or character variables, they are first converted to numeric.

Usage

dftomat(X)

Arguments

X

A data frame to be converted to a numeric matrix.

Value

A numeric matrix corresponding to the input data frame.


engression documentation built on April 16, 2026, 9:06 a.m.