Learn R Programming

engression (version 0.1.5)

energyloss: Energy Loss Calculation

Description

This function calculates the energy loss for given tensors. The loss is calculated as the mean of the L2 norms between yt and mxt and between yt and mxpt, subtracted by half the mean of the L2 norm between mxt and mxpt.

Usage

energyloss(yt, mxt, mxpt)

Value

A scalar representing the calculated energy loss.

Arguments

yt

A tensor representing the target values.

mxt

A tensor representing the model's stochastic predictions.

mxpt

A tensor representing another draw of the model's stochastic predictions.