View source: R/energylossall.R
| energylossall | R Documentation |
This function calculates the energy loss for given tensors, similar to energyloss(). The loss is calculated
as the mean of the L2 norms between yt and mxt and between yt and mxpt,
subtracted by half the mean of the L2 norm between mxt and mxpt. Unlike energyloss(), this function
also returns the prediction loss s1 = E(|yt-mxt|) and variance loss s2 = E(|mxt-mxpt'|) as part of the output.
energylossall(yt, mxt, mxpt)
yt |
A tensor representing the target values. |
mxt |
A tensor representing the model's stochastic predictions. |
mxpt |
A tensor representing another draw of the model's stochastic predictions. |
A vector containing the calculated energy loss, s1, and s2.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.