View source: R/energylossbeta.R
| energylossbeta | R Documentation |
This function calculates the energy loss for given tensors. The loss is calculated
as the mean of the L2 norms between yt and mxt and between yt and mxpt,
each raised to the power of beta, subtracted by half the mean of the L2 norm between mxt and mxpt,
also raised to the power of beta.
energylossbeta(yt, mxt, mxpt, beta)
yt |
A tensor representing the target values. |
mxt |
A tensor representing the model's stochastic predictions. |
mxpt |
A tensor representing another draw of the model's stochastic predictions. |
beta |
A numeric value for scaling the energy loss. |
A scalar representing the calculated energy loss.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.