This function calculates the energy loss for given tensors. The loss is calculated
as the mean of the L2 norms between yt and mxt and between yt and mxpt,
subtracted by half the mean of the L2 norm between mxt and mxpt.
energyloss(yt, mxt, mxpt)A scalar representing the calculated energy loss.
A tensor representing the target values.
A tensor representing the model's stochastic predictions.
A tensor representing another draw of the model's stochastic predictions.